@@ -30,6 +30,7 @@
 #include <stdlib.h> /* atoi() calloc() exit() free()
     malloc() strtol() */
 #include <string.h> /* strcmp() strdup() strlen() */
+#include <stdio.h> /* FILE decl for dd_esb.h */
 
 /* Windows specific header files */
 #if defined(_WIN32) && defined(HAVE_STDAFX_H)
@@ -38,6 +39,9 @@
 
 #include "dwarf.h"
 #include "libdwarf.h"
+#include "dd_defined_types.h"
+#include "dd_checkutil.h"
+#include "dd_glflags.h"
 #include "dd_globals.h"
 #include "dd_dwconf.h"
 #include "dd_getopt.h"
@@ -468,7 +472,8 @@ static const char *usage_long_text[] = {
 "                         .note.gnu.build-id",
 "     --print-gnu-debuglink Print .gnu_debuglink,",
 "                         .note.gnu.build-id sections",
-"     --print-debug-addr  Print .debug_addr section",
+"     --print-debug-addr  Print .debug_addr section. (If DWARF4",
+"                         add option -i to make this work)",
 "     --print-debug-gnu   Print .debug_gnu_pubtypes and",
 "                         .debug_gnu_pubnames sections",
 "     --print-debug-names Print .debug_names section",
